==> spip_4.0.4.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_hac.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=hac
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => '!@nom@وەشئامای',
	'c_accueil_configurer_site' => 'پەڕیانەکەو وېت ڕېکۋزە',
	'c_accueil_configurer_site_texte' => 'یۊ چە ئا یەکەمین چېۋا کە مشیۊ ئەنچامدریۊ نامەنیای پەڕیانەکەو وېتا. ئیسە نامۍ نریا"@nom@". نامۊ سایتەکۍ لای سەری پەڕەکەیۆ نیشانمڎریۊ. بە کرتەکەدەی سەرو نامەکۍ، متاۋی نامەکۍ فاڕی، ھەر پاسە لۆگۆ و  نیشاندەرش پەی بنیەرە.',
	'c_accueil_publication' => 'ۋەڵاکەردەی!',
	'c_accueil_publication_texte' => 'پەی ۋەلاکەردەی پەڕېۋی، پېۋیستا تۆ بابەتېۋ درۊسکەری.
		ھەر پاسە پېۋیستا کە تۊ بەڕادەی کەم بەشېۋ درۊسکەری.
متاۋی بە کرتەکردەی چە شریتۊ سەر پەڕەیەنە سەرو « ئەرەنیای » دماو ئانەیە سەرو « بەشی » .',
	'c_accueil_texte' => 'تۊ تەنیا ئامانی دلۍ چە بەشی تایبەتوSPIP.',
	'c_accueil_texte_revenir' => '		 ئی پەڕە دمایین چالاکی دەسکاری ئی پەڕیانەیە نیشانمڎۊ. 
		تۊ متاۋی گرد کاتېۋ بە کرتەکەردەی سەرو "ھېماو ساتی" سەردانی ئی پەڕەیە کەری، چە لای سەریۆ، چېرو نامەکۊ وېتەنە.',
	'c_article_redaction' => 'دەسکاری ئی بابەتۍ بەردەۋاما',
	'c_article_redaction_redacteur' => 'دەسکاری ئی بابەتۍ بەردەۋاما',
	'c_article_redaction_redacteur_texte' => 'پەی پېشنیارکەردەو بابەتەکۊ وېت بە سەرپەرشتیکەرو پەڕیانەکەی و  نۋیسەرا تەری، "دەسکاری بەردەۋاما" فاڕە پەی "کیاستەی پەی پەسەڼکەردەی".',
	'c_article_redaction_texte' => 'پەی ۋەڵاکەردەو ئی بابەتۍ سەرو ئی پەڕیانەیۊ، بارەکەی فاڕە.
چە ڕیزو سەرو خشتەکو لاکاۋە، "بەردەۋامی دەسکاری" فاڕە بە "ۋەڵاکەردەی".',
	'c_articles_creer' => 'چنی بابەتېۋە منیەیرە؟',
	'c_articles_creer_texte' => 'تۆ نمەتاۋی چە ئی پەڕەیۆ بابەتېۋە بنیەیرە		تاکو بەڕادەی کەم یەک بەش سەرو پەڕیانەکەیۆ نەبۊ.
		تۊ چە شریتۊ لاو سەری « بەشەکانە »،   « دەسکاری » چېرو .',
	'c_job' => 'ھەرمۍ پەی ئەنجمدای...',
	'c_job_texte' => 'ئی پەڕە ئا ئەرکا ڕیزکەرۊ، تاکو چە لایەنو SPIP ئەنچامدریا. ئا ئەرکۍ بە نۊرە و تەرتیبکریا یان جار جار پەی ئامادەکارییە سەختەکا چە ڕاو ھۊرئاۋېزیاکاۋە، پېسە کیاستەی ئیمەیلی بە کۊمەڵی.',
	'c_rubrique_publier' => 'بابەتېۋە بنیەرە',
	'c_rubrique_publier_texte' => 'تەنیا ئا کاتە بەشېۋ سەرو پەڕیانەی گردینەیۆ بەرگنۊ، کە بەڕادەی کەم چېۋېۋی ۋەڵاکریاش چنە بۊ، پەی نموونەی بابەتېۋی ۋەڵاکریێ.
پېسە بابەتېۋە منریۊرە. تۊ متاۋی ئانەیە چی پەڕەنە کەری، چېرو شناسەو بەشەکەیەنە.',
	'c_rubriques_creer' => 'بەشېۋ درۊسکەرە!',
	'c_rubriques_creer_texte' => 'بەشەکۍ پېکئامای بنەڕەتی پەڕیانەیەنۍ، تۊ متاۋی چە ھەر یۊ چە ئاڎیشانە بابەت بنیەیرە. بە درۊسکەردەی یەکەمین بەشی دەسپنەکەرە.',
	'c_sites_creer' => 'چنی پەڕیانېۋ درۊسکەری یان ماری؟',
	'c_sites_creer_texte' => 'تۆ تەنیا متاۋی پەڕیانېۋ درۊسکەری یان چە پەڕېۋۆ باری، کە بەشېۋ چە پەڕیانەکەو وېتەنە بۊ.
تۊ متاۋی چە شرېتۊ لاو سەریۆ چە« دەسکاری », puis « بەشەکۍ ».',

	// E
	'explication_activer_compagnon' => 'ھامڕای چڼ سەرنجېۋش سەرو پەڕېۋو بەشی تایبەتو سەرپەرشتیSPIP نیێنېرە.
گەرەکتا چالاکشکەری؟',
	'explication_reinitialiser_compagnon' => 'پەیامەکۍ نۋیسەرېۋی دیېنۍ ئیتر نیشانمەدریا.
گەرەکتا ئی پەیاما نۊژەنکەریۊ؟',

	// L
	'label_activer_compagnon' => 'ھامڕا چالاککریۊ؟',
	'label_reinitialiser_compagnon' => 'پەیامۍ ھامڕاکا نۊژەنکریاۋە؟',

	// O
	'ok' => 'پەسەندکەردەی',
	'ok_bien' => 'خاس!',
	'ok_jai_compris' => 'بە من یاۋا!',
	'ok_merci' => 'سپاس',
	'ok_parfait' => 'فرە خاسا!',

	// R
	'reinitialisation' => 'ھەرمانۆۋزتەی',
	'reinitialisation_ok' => 'ھەرمانۆۋزتەکەی تەمامیا',
	'reinitialiser' => 'ھەرمانۆۋزتەی',
	'reinitialiser_moi' => 'بەڵۍ، تەنیا ئانۍ کە وەنېنېمۊ',
	'reinitialiser_tous' => 'بەڵۍ، ھەر کەس نۋیسەر بۊ',

	// T
	'titre_compagnon' => 'ھامڕێ',
	'titre_page_configurer_compagnon' => 'ڕېکۋزتەو ھامڕاکا'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_hac.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// C
	'c_accueil_bienvenue' => '!@nom@وەشئامای',
	'c_accueil_configurer_site' => 'پەڕیانەکەو وېت ڕېکۋزە',
	'c_accueil_configurer_site_texte' => 'یۊ چە ئا یەکەمین چېۋا کە مشیۊ ئەنچامدریۊ نامەنیای پەڕیانەکەو وېتا. ئیسە نامۍ نریا"@nom@". نامۊ سایتەکۍ لای سەری پەڕەکەیۆ نیشانمڎریۊ. بە کرتەکەدەی سەرو نامەکۍ، متاۋی نامەکۍ فاڕی، ھەر پاسە لۆگۆ و  نیشاندەرش پەی بنیەرە.',
	'c_accueil_publication' => 'ۋەڵاکەردەی!',
	'c_accueil_publication_texte' => 'پەی ۋەلاکەردەی پەڕېۋی، پېۋیستا تۆ بابەتېۋ درۊسکەری.
		ھەر پاسە پېۋیستا کە تۊ بەڕادەی کەم بەشېۋ درۊسکەری.
متاۋی بە کرتەکردەی چە شریتۊ سەر پەڕەیەنە سەرو « ئەرەنیای » دماو ئانەیە سەرو « بەشی » .',
	'c_accueil_texte' => 'تۊ تەنیا ئامانی دلۍ چە بەشی تایبەتوSPIP.',
	'c_accueil_texte_revenir' => '		 ئی پەڕە دمایین چالاکی دەسکاری ئی پەڕیانەیە نیشانمڎۊ. 
		تۊ متاۋی گرد کاتېۋ بە کرتەکەردەی سەرو "ھېماو ساتی" سەردانی ئی پەڕەیە کەری، چە لای سەریۆ، چېرو نامەکۊ وېتەنە.',
	'c_article_redaction' => 'دەسکاری ئی بابەتۍ بەردەۋاما',
	'c_article_redaction_redacteur' => 'دەسکاری ئی بابەتۍ بەردەۋاما',
	'c_article_redaction_redacteur_texte' => 'پەی پېشنیارکەردەو بابەتەکۊ وېت بە سەرپەرشتیکەرو پەڕیانەکەی و  نۋیسەرا تەری، "دەسکاری بەردەۋاما" فاڕە پەی "کیاستەی پەی پەسەڼکەردەی".',
	'c_article_redaction_texte' => 'پەی ۋەڵاکەردەو ئی بابەتۍ سەرو ئی پەڕیانەیۊ، بارەکەی فاڕە.
چە ڕیزو سەرو خشتەکو لاکاۋە، "بەردەۋامی دەسکاری" فاڕە بە "ۋەڵاکەردەی".',
	'c_articles_creer' => 'چنی بابەتېۋە منیەیرە؟',
	'c_articles_creer_texte' => 'تۆ نمەتاۋی چە ئی پەڕەیۆ بابەتېۋە بنیەیرە		تاکو بەڕادەی کەم یەک بەش سەرو پەڕیانەکەیۆ نەبۊ.
		تۊ چە شریتۊ لاو سەری « بەشەکانە »،   « دەسکاری » چېرو .',
	'c_job' => 'ھەرمۍ پەی ئەنجمدای...',
	'c_job_texte' => 'ئی پەڕە ئا ئەرکا ڕیزکەرۊ، تاکو چە لایەنو SPIP ئەنچامدریا. ئا ئەرکۍ بە نۊرە و تەرتیبکریا یان جار جار پەی ئامادەکارییە سەختەکا چە ڕاو ھۊرئاۋېزیاکاۋە، پېسە کیاستەی ئیمەیلی بە کۊمەڵی.',
	'c_rubrique_publier' => 'بابەتېۋە بنیەرە',
	'c_rubrique_publier_texte' => 'تەنیا ئا کاتە بەشېۋ سەرو پەڕیانەی گردینەیۆ بەرگنۊ، کە بەڕادەی کەم چېۋېۋی ۋەڵاکریاش چنە بۊ، پەی نموونەی بابەتېۋی ۋەڵاکریێ.
پېسە بابەتېۋە منریۊرە. تۊ متاۋی ئانەیە چی پەڕەنە کەری، چېرو شناسەو بەشەکەیەنە.',
	'c_rubriques_creer' => 'بەشېۋ درۊسکەرە!',
	'c_rubriques_creer_texte' => 'بەشەکۍ پېکئامای بنەڕەتی پەڕیانەیەنۍ، تۊ متاۋی چە ھەر یۊ چە ئاڎیشانە بابەت بنیەیرە. بە درۊسکەردەی یەکەمین بەشی دەسپنەکەرە.',
	'c_sites_creer' => 'چنی پەڕیانېۋ درۊسکەری یان ماری؟',
	'c_sites_creer_texte' => 'تۆ تەنیا متاۋی پەڕیانېۋ درۊسکەری یان چە پەڕېۋۆ باری، کە بەشېۋ چە پەڕیانەکەو وېتەنە بۊ.
تۊ متاۋی چە شرېتۊ لاو سەریۆ چە« دەسکاری », puis « بەشەکۍ ».',

	// E
	'explication_activer_compagnon' => 'ھامڕای چڼ سەرنجېۋش سەرو پەڕېۋو بەشی تایبەتو سەرپەرشتیSPIP نیێنېرە.
گەرەکتا چالاکشکەری؟',
	'explication_reinitialiser_compagnon' => 'پەیامەکۍ نۋیسەرېۋی دیېنۍ ئیتر نیشانمەدریا.
گەرەکتا ئی پەیاما نۊژەنکەریۊ؟',

	// L
	'label_activer_compagnon' => 'ھامڕا چالاککریۊ؟',
	'label_reinitialiser_compagnon' => 'پەیامۍ ھامڕاکا نۊژەنکریاۋە؟',

	// O
	'ok' => 'پەسەندکەردەی',
	'ok_bien' => 'خاس!',
	'ok_jai_compris' => 'بە من یاۋا!',
	'ok_merci' => 'سپاس',
	'ok_parfait' => 'فرە خاسا!',

	// R
	'reinitialisation' => 'ھەرمانۆۋزتەی',
	'reinitialisation_ok' => 'ھەرمانۆۋزتەکەی تەمامیا',
	'reinitialiser' => 'ھەرمانۆۋزتەی',
	'reinitialiser_moi' => 'بەڵۍ، تەنیا ئانۍ کە وەنېنېمۊ',
	'reinitialiser_tous' => 'بەڵۍ، ھەر کەس نۋیسەر بۊ',

	// T
	'titre_compagnon' => 'ھامڕێ',
	'titre_page_configurer_compagnon' => 'ڕېکۋزتەو ھامڕاکا',
];
